Index: /trunk/src/VBox/Main/GuestImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/GuestImpl.cpp	(revision 35128)
+++ /trunk/src/VBox/Main/GuestImpl.cpp	(revision 35129)
@@ -692,8 +692,10 @@
                                                     Bstr("").raw() /* Username */,
                                                     Bstr("").raw() /* Password */,
-                                                    5 * 1000 /* Wait 5s for getting the process started */,
+                                                    10 * 1000 /* Wait 10s for getting the process started */,
                                                     &uPID, progressInstaller.asOutParam(), &vrc);
                 if (SUCCEEDED(rc))
                 {
+                    LogRel(("Guest Additions update is running ...\n"));
+
                     /* If the caller does not want to wait for out guest update process to end,
                      * complete the progress object now so that the caller can do other work. */
@@ -703,5 +705,5 @@
                         aTask->progress->SetCurrentOperationProgress(70);
 
-                    LogRel(("Guest Additions update is running ...\n"));
+                    /* Wait until the Guest Additions installer finishes ... */
                     while (   SUCCEEDED(progressInstaller->COMGETTER(Completed(&fCompleted)))
                            && !fCompleted)
@@ -719,5 +721,5 @@
                             break;
                         }
-                        RTThreadSleep(1);
+                        RTThreadSleep(100);
                     }
 
@@ -737,4 +739,6 @@
                             else
                             {
+                                LogRel(("Guest Additions update failed (Exit code=%u, Status=%u, Flags=%u)\n",
+                                        uRetExitCode, uRetStatus, uRetFlags));
                                 rc = TaskGuest::setProgressErrorInfo(VBOX_E_IPRT_ERROR, aTask->progress,
                                                                      Guest::tr("Guest Additions update failed with exit code=%u (status=%u, flags=%u)"),
@@ -745,4 +749,5 @@
                                  && fCanceled)
                         {
+                            LogRel(("Guest Additions update was canceled\n"));
                             rc = TaskGuest::setProgressErrorInfo(VBOX_E_IPRT_ERROR, aTask->progress,
                                                                  Guest::tr("Guest Additions update was canceled by the guest with exit code=%u (status=%u, flags=%u)"),
@@ -751,5 +756,5 @@
                         else
                         {
-                            /* Guest Additions update was canceled by the user. */
+                            LogRel(("Guest Additions update was canceled by the user\n"));
                         }
                     }
